==> opensearch-dashboards-2.9.0-1-aarch64.pkg.tar.xz: usr/share/opensearch-dashboards/src/plugins/data/common/opensearch_query/opensearch_query/filter_matches_index.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.filterMatchesIndex = filterMatchesIndex;

/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/*
 * TODO: We should base this on something better than `filter.meta.key`. We should probably modify
 * this to check if `filter.meta.index` matches `indexPattern.id` instead, but that's a breaking
 * change.
 */
function filterMatchesIndex(filter, indexPattern) {
  var _filter$meta;

  if (!((_filter$meta = filter.meta) !== null && _filter$meta !== void 0 && _filter$meta.key) || !indexPattern) {
    return true;
  }

  return indexPattern.fields.some(field => field.name === filter.meta.key);
}

==> opensearch-dashboards-2.12.0-1-aarch64.pkg.tar.xz: usr/share/opensearch-dashboards/src/plugins/data/common/opensearch_query/opensearch_query/filter_matches_index.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.filterMatchesIndex = filterMatchesIndex;
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

function filterMatchesIndex(filter, indexPattern) {
  var _filter$meta, _filter$meta2;
  if (!((_filter$meta = filter.meta) !== null && _filter$meta !== void 0 && _filter$meta.key) || !indexPattern) {
    return true;
  }
  if (((_filter$meta2 = filter.meta) === null || _filter$meta2 === void 0 ? void 0 : _filter$meta2.type) === 'custom') {
    return filter.meta.index === indexPattern.id;
  }
  return indexPattern.fields.some(field => field.name === filter.meta.key);
}
